@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 import requests
 
@@ -54,7 +54,7 @@ class TestHttpStore(base.StoreBaseTest,
                             'ho', 'rt', ' a', 'nd', ' s', 'to', 'ut', '\n']
         loc = location.get_location_from_uri(uri, conf=self.conf)
         (image_file, image_size) = self.store.get(loc)
-        self.assertEqual(image_size, 31)
+        self.assertEqual(31, image_size)
         chunks = [c for c in image_file]
         self.assertEqual(expected_returns, chunks)
 
@@ -86,10 +86,10 @@ class TestHttpStore(base.StoreBaseTest,
         loc = location.get_location_from_uri(uri, conf=self.conf)
         (image_file, image_size) = self.store.get(loc)
         self.assertEqual(0, len(responses))
-        self.assertEqual(image_size, 31)
+        self.assertEqual(31, image_size)
 
         chunks = [c for c in image_file]
-        self.assertEqual(chunks, expected_returns)
+        self.assertEqual(expected_returns, chunks)
 
     def test_http_get_max_redirects(self):
         self._mock_requests()
@@ -184,6 +184,15 @@ class TestHttpStore(base.StoreBaseTest,
             self.assertRaises(exceptions.BadStoreUri,
                               location.get_location_from_uri, uri)
 
+    def test_http_store_location_get_uri(self):
+        """Test for HTTP URI with and without query"""
+        uris = ["http://netloc/path/to/file.tar.gz"
+                "http://netloc/path/to/file.tar.gz?query=text",
+                ]
+        for uri in uris:
+            loc = location.get_location_from_uri(uri, conf=self.conf)
+            self.assertEqual(uri, loc.store_location.get_uri())
+
     def test_http_get_raises_remote_service_unavailable(self):
         """Test http store raises RemoteServiceUnavailable."""
         uri = "http://netloc/path/to/file.tar.gz"
